@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: apr 27 2018 (23:32) 
 ## Version: 
-## Last-Updated: Apr 15 2021 (11:01) 
+## Last-Updated: okt 13 2021 (16:10) 
 ##           By: Brice Ozenne
-##     Update #: 274
+##     Update #: 302
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -38,6 +38,7 @@ testArgs <- function(name.call,
                      strata.resampling,
                      hierarchical,
                      neutral.as.uninf,
+                     add.halfNeutral,
                      operator,
                      censoring,
                      seed,
@@ -73,7 +74,7 @@ testArgs <- function(name.call,
     argnames <- c("treatment", "endpoint", "type", "threshold", "status", "strata")
 
     D <- length(endpoint) 
-    D.TTE <- sum(type == 3) # number of time to event endpoints
+    D.TTE <- sum(type == "tte") # number of time to event endpoints
     level.treatment <- levels(as.factor(data[[treatment]])) 
     if(is.null(strata)){
         n.strata <- 1
@@ -102,7 +103,7 @@ testArgs <- function(name.call,
     if(any(is.na(status))){
         stop("BuyseTest: \'status\' must not contain NA. \n")
     }
-    index.pb <- which(status[type==3] == "..NA..")
+    index.pb <- which(status[type=="tte"] == "..NA..") 
     if(length(index.pb)>0){
         if(all(attr(censoring,"original")[index.pb] %in% names(data))){
             stop("BuyseTest: wrong specification of \'status\'. \n",
@@ -112,17 +113,29 @@ testArgs <- function(name.call,
         }else{        
             stop("BuyseTest: wrong specification of \'status\'. \n",
                  "\'status\' must indicate a variable in data for TTE endpoints. \n",
-                 "TTE endoints: ",paste(endpoint[type==3],collapse=" "),"\n",
-                 "proposed \'status\' for these endoints: ",paste(status[type==3],collapse=" "),"\n")
+                 "TTE endoints: ",paste(endpoint[type=="tte"],collapse=" "),"\n",
+                 "proposed \'status\' for these endoints: ",paste(status[type=="tte"],collapse=" "),"\n")
         }
     }
-    if(any(status[type!=3] !="..NA..") ){
+    index.pb <- which(status[type=="gaussian"] == "..NA..") 
+    if(length(index.pb)>0){
+        stop("BuyseTest: wrong specification of \'std\'. \n",
+             "\'std\' must indicate a variable in data for Gaussian endpoints. \n",
+             "Gaussian endoints: ",paste(endpoint[type==4],collapse=" "),"\n",
+             "proposed \'gaussian\' for these endoints: ",paste(status[type==4],collapse=" "),"\n")
+    }
+    if(any(status[type %in% c("bin","cont")] !="..NA..") ){
         stop("BuyseTest: wrong specification of \'status\'. \n",
              "\'status\' must be \"..NA..\" for binary or continuous endpoints. \n",
-             "endoints : ",paste(endpoint[type!=3],collapse=" "),"\n",
-             "proposed \'status\' for these endoints: ",paste(status[type!=3],collapse=" "),"\n")
+             "endoints : ",paste(endpoint[type %in% c("bin","cont")],collapse=" "),"\n",
+             "proposed \'status\' for these endoints: ",paste(status[type %in% c("bin","cont")],collapse=" "),"\n")
+    }
+    Ustatus.TTE <- unique(status[type=="tte"])
+
+    if(any(Ustatus.TTE %in% names(data) == FALSE)){
+        stop("BuyseTest: variable(s) \'status\': \"",paste0(Ustatus.TTE[Ustatus.TTE %in% names(data) == FALSE], collapse = "\" \""),"\" \n",
+             "not found in argument \'data\'.\n")
     }
-    Ustatus.TTE <- unique(status[type==3])
 
     if(is.null(strata)){
         if(any(sapply(Ustatus.TTE, function(iS){sum(data[[iS]]!=0)})==0)){
@@ -136,17 +149,29 @@ testArgs <- function(name.call,
             warning("BuyseTest: time to event variables with only censored events in at least one strata \n")
         }
     }
-    
+
     ## ** censoring
-    if(any(is.na(censoring))){
-        stop("BuyseTest: wrong specification of \'censoring\'. \n",
-             "\'censoring\' must be \'as.character(NA)\', \"left\", or \"right\" \n",
-             "incorrect \'censoring\' value(s): \"",paste(attr(censoring,"original")[is.na(censoring)], collapse = "\" \""),"\" \n")
-    }
-    if(any(censoring[type==3]==0)){
-        stop("BuyseTest: wrong specification of \'censoring\'. \n",
-             "\'censoring\' must be \"left\" or \"right\" for TTE endpoints \n")
+    if(any(type=="gaus")){ ## iid has been internally stored in the censoring variable
+        censoring.gaus <- na.omit(censoring[type=="gaus"])
+        if(length(censoring.gaus)>0 && any(censoring.gaus %in% names(data) == FALSE)){
+            stop("BuyseTest: wrong specification of \'iid\'. \n",
+                 "\'iid\' must indicate a variable in argument \'data\'. \n",
+                 "incorrect \'iid\' value(s): \"",paste(censoring.gaus[censoring.gaus %in% names(data) == FALSE], collapse = "\" \""),"\" \n")
+        }
+    }else if(any(type=="tte")){
+        censoring.tte <- censoring[type=="tte"]
+        if(any(is.na(censoring.tte))){
+            stop("BuyseTest: wrong specification of \'censoring\'. \n",
+                 "\'censoring\' must be \"left\", or \"right\" for time to event endpoints. \n",
+                 "incorrect \'censoring\' value(s): \"",paste(censoring.tte[is.na(censoring.tte)], collapse = "\" \""),"\" \n")
+        }
+        if(any(censoring.tte %in% c("left","right") == FALSE)){
+            stop("BuyseTest: wrong specification of \'censoring\'. \n",
+                 "\'censoring\' must be \"left\", or \"right\" \n",
+                 "incorrect \'censoring\' value(s): \"",paste(censoring.tte[censoring.tte %in% c("left","right") == FALSE], collapse = "\" \""),"\" \n")
+        }
     }
+    
 
     ## ** cpus
     if(cpus>1){
@@ -163,14 +188,14 @@ testArgs <- function(name.call,
         stop("BuyseTest: wrong specification of \'scoring.rule\'. \n",
              "valid values: \"Gehan\" \"Gehan corrected\" \"Peron\" \"Peron corrected\". \n")
     }
-    if(scoring.rule>0 && any(censoring>1)){
+    if(scoring.rule>0 && any(censoring=="left")){
         warning("The Peron's scoring rule does not support left-censored endpoints \n",
                 "For those endpoints, the Gehan's scoring rule will be used instead.")
     }
 
     ## ## ** model.tte
     if(!is.null(model.tte)){
-        endpoint.UTTE <- unique(endpoint[type==3])
+        endpoint.UTTE <- unique(endpoint[type=="tte"])
         D.UTTE <- length(endpoint.UTTE)
 
         if(!is.list(model.tte) || length(model.tte) != D.UTTE){
@@ -205,7 +230,7 @@ testArgs <- function(name.call,
     ## ** data (endpoints)
 
     ## *** binary endpoints
-    index.Bin <- which(type==1)
+    index.Bin <- which(type=="bin")
     if(length(index.Bin)>0){
         for(iBin in index.Bin){ ## iterY <- 1
             if(length(unique(na.omit(data[[endpoint[iBin]]])))>2){
@@ -219,7 +244,7 @@ testArgs <- function(name.call,
     }
 
     ## *** continuous endpoints
-    index.Cont <- which(type==2)
+    index.Cont <- which(type=="cont")
     if(length(index.Cont)>0){
         for(iCont in index.Cont){
             validNumeric(data[[endpoint[iCont]]],
@@ -235,8 +260,8 @@ testArgs <- function(name.call,
     }
 
     ## *** time to event endpoint
-    index.TTE <- which(type==3)
-    status.TTE <- status[type==3]
+    index.TTE <- which(type=="tte")
+    status.TTE <- status[type=="tte"]
     if(length(index.TTE)>0){
         validNames(data,
                    name1 = "data",
@@ -261,6 +286,23 @@ testArgs <- function(name.call,
         }
     }
 
+    ## *** Gaussian endpoints
+    index.Gaus <- which(type=="gaus")
+    if(length(index.Gaus)>0){
+        for(iGaus in index.Gaus){
+            validNumeric(data[[endpoint[iGaus]]],
+                         name1 = endpoint[iGaus],
+                         valid.length = NULL,
+                         refuse.NA =  FALSE,
+                         method = "BuyseTest")
+            validNumeric(data[[status[iGaus]]],
+                         name1 = status[iGaus],
+                         valid.length = NULL,
+                         refuse.NA =  FALSE,
+                         method = "BuyseTest")
+        }
+    }
+
     ## ** endpoint
     validNames(data,
                name1 = "data",
@@ -330,6 +372,11 @@ testArgs <- function(name.call,
                  valid.length = D,
                  method = "BuyseTest")
 
+    ## ** add.halfNeutral
+    validLogical(add.halfNeutral,
+                 valid.length = 1,
+                 method = "BuyseTest")
+
     ## ** operator
     if(any(is.na(operator))){
         stop("BuyseTest: Wrong specification of \'operator\'. \n",
@@ -370,11 +417,11 @@ testArgs <- function(name.call,
                  method = "BuyseTest")
 
     ## check threshold at 1/2 for binary endpoints
-    if(any(threshold[type==1]!=1/2)){
+    if(any(threshold[type=="bin"]!=1/2)){
         stop("BuyseTest: wrong specification of \'threshold\'. \n",
              "\'threshold\' must be 1/2 for binary endpoints (or equivalently NA) \n",
-             "proposed \'threshold\' : ",paste(threshold[type==1],collapse=" "),"\n",
-             "binary endpoint(s) : ",paste(endpoint[type==1],collapse=" "),"\n")
+             "proposed \'threshold\' : ",paste(threshold[type=="bin"],collapse=" "),"\n",
+             "binary endpoint(s) : ",paste(endpoint[type=="bin"],collapse=" "),"\n")
     }
     
     ## Check that the thresholds related to the same endoints are strictly decreasing
@@ -392,7 +439,6 @@ testArgs <- function(name.call,
              "Endpoints must be used with strictly decreasing threshold when re-used with lower priority. \n",
              "Problematic endpoints: \"",paste0(names(vec.test)[vec.test>0], collapse = "\" \""),"\"\n")        
     }
-
     ## ** trace
     validInteger(trace,
                  valid.length = 1,
@@ -425,8 +471,8 @@ testArgs <- function(name.call,
     }
     
     ## ** type
-    if(any(type %in% 1:3 == FALSE)){
-        txt <- type[type %in% 1:3 == FALSE]
+    if(any(type %in% c("bin","cont","tte","gaus") == FALSE)){
+        txt <- type[type %in% c("bin","cont","tte","gaus") == FALSE]
         stop("BuyseTest: wrong specification of \'type\' \n",
              "valid values: \"binary\" \"continuous\" \"timetoevent\" \n",
              "incorrect values: \"",paste(txt, collapse = "\" \""),"\" \n")
