@@ -34,13 +34,15 @@ setClass(
       n.resampling = "numeric",
       strata.resampling = "character",
       neutral.as.uninf = "logical",
+      add.halfNeutral = "logical",
       order.Hprojection = "numeric",
       precompute = "logical",
       print.display = "character",
       statistic = "character",
       summary.display = "list",
       trace = "numeric",
-      transformation = "logical"
+      transformation = "logical",
+      warning.correction = "numeric"
   ),
 
 ### ** Check validity of the object
@@ -119,14 +121,18 @@ setClass(
                    valid.length = 1,
                    method = "Class BuyseTest.options")
       validCharacter(object@strata.resampling,
-                   name1 = "@n.resampling",
-                   valid.values = c(as.character(NA),"treatment","strata"),
-                   valid.length = 1,
-                   method = "Class BuyseTest.options")
+                     name1 = "@n.resampling",
+                     valid.values = c(as.character(NA),"treatment","strata"),
+                     valid.length = 1,
+                     method = "Class BuyseTest.options")
       validLogical(object@neutral.as.uninf,
                    name1 = "@neutral.as.uninf",
                    valid.length = 1,
                    method = "Class BuyseTest.options")
+      validLogical(object@add.halfNeutral,
+                   name1 = "@add.halfNeutral",
+                   valid.length = 1,
+                   method = "Class BuyseTest.options")
       validInteger(object@order.Hprojection,
                    name1 = "@order.Hprojection",
                    min = 1,
@@ -161,6 +167,12 @@ setClass(
                    name1 = "@transformation",
                    valid.length = 1,
                    method = "Class BuyseTest.options")
+      validNumeric(object@warning.correction,
+                   name1 = "@warning.correction",
+                   min = 0,
+                   max = 1,
+                   valid.length = 1,
+                   method = "Class BuyseTest.options")
       return(TRUE)} 
 )
 
