@@ -97,6 +97,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
   double iWeight=1;
   bool iUpdateRPNeutral;
   bool iUpdateRPUninf;
+  double iRho; arma::mat iMatRho;
 
   // counts
   count_favorable = 0;
@@ -139,7 +140,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
   std::vector<int> vecCol_Dnuisance_C, vecCol_Dnuisance_T;
   std::vector<std::vector<double>> vecValue_Dnuisance_C(4), vecValue_Dnuisance_T(4);
 			 
-  if(returnIID > 1 && method >= 4){
+  if(returnIID > 1 && method >= 5){
     // aggregated over all pairs
     Dscore_Dnuisance_C.resize(p_C, 4);
     Dscore_Dnuisance_C.fill(0.0);
@@ -181,7 +182,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
     if(debug>3){Rcpp::Rcout << "("<< endpointT[iter_T] << ";" << endpointC[iter_C] << ";" << threshold <<") ";}
     
     // *** compute score
-    if(evalM1 && method > 3){ // Previously analyzed endpoint with Peron's scoring rule. Extract previous score for the residual pairs.
+    if(evalM1 && method >= 5){ // Previously analyzed endpoint with Peron's scoring rule. Extract previous score for the residual pairs.
       iPairScore[0] = RP_score(iter_pair,0);
       iPairScore[1] = RP_score(iter_pair,1);
       iPairScore[2] = RP_score(iter_pair,2);
@@ -196,18 +197,26 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
       }
     }else if(method == 1){ // continuous or binary endpoint
       iPairScore = calcOnePair_Continuous(endpointT[iter_T] - endpointC[iter_C], threshold);
-    }else if(method == 2){ // time to event endpoint with Gehan's scoring rule (right-censored, survival or competing risks)
+    }else if(method == 2){
+      if(survTimeC.n_rows>0){
+	iMatRho = arma::cor(survTimeC.col(iter_C), survTimeT.col(iter_T), 0);
+	iRho = iMatRho(0,0);
+      }else{
+	iRho = 0;
+      }
+      iPairScore = calcOnePair_Gaussian(endpointT[iter_C], endpointC[iter_T], statusC[iter_C], statusT[iter_T], iRho, threshold);
+    }else if(method == 3){ // time to event endpoint with Gehan's scoring rule (right-censored, survival or competing risks)
       iPairScore = calcOnePair_TTEgehan(endpointT[iter_T] - endpointC[iter_C], statusC[iter_C], statusT[iter_T], threshold);
-    }else if(method == 3){ // time to event endpoint with Gehan's scoring rule (left-censored, survival or competing risks)
+    }else if(method == 4){ // time to event endpoint with Gehan's scoring rule (left-censored, survival or competing risks)
       iPairScore = calcOnePair_TTEgehan2(endpointT[iter_T] - endpointC[iter_C], statusC[iter_C], statusT[iter_T], threshold);
-    }else if(method == 4){  // time to event endpoint with Peron's scoring rule (right-censored, survival)
+    }else if(method == 5){  // time to event endpoint with Peron's scoring rule (right-censored, survival)
       iPairScore = calcOnePair_SurvPeron(endpointC[iter_C], endpointT[iter_T], statusC[iter_C], statusT[iter_T], threshold,
 					 survTimeC.row(iter_C), survTimeT.row(iter_T),
 					 survJumpC, survJumpT, lastSurv(0), lastSurv(1),
 					 iDscore_Dnuisance_C, iDscore_Dnuisance_T,
 					 p_C, p_T, precompute, returnIID);
 
-    }else if(method == 5){  // time to event endpoint with Peron's scoring rule (right-censored, competing risks)
+    }else if(method == 6){  // time to event endpoint with Peron's scoring rule (right-censored, competing risks)
       iPairScore = calcOnePair_CRPeron(endpointC[iter_C], endpointT[iter_T], statusC[iter_C], statusT[iter_T], threshold,
 				       survTimeC.row(iter_C), survTimeT.row(iter_T),
 				       survJumpC, survJumpT, lastSurv(0), lastSurv(1), lastSurv(2), lastSurv(3),
@@ -216,12 +225,12 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
     }
 
     // *** operator
-    if(op<0 && !(evalM1 && method > 3)){
+    if(op<0 && !(evalM1 && method >= 5)){
       iTempoOperatorDouble = iPairScore[0];
       iPairScore[0] = iPairScore[1];
       iPairScore[1] = iTempoOperatorDouble;
 
-      if((returnIID > 1) && (method >= 4)){ 
+      if((returnIID > 1) && (method >= 5)){ 
 	iTempoOperatorCol = iDscore_Dnuisance_C.col(0);
 	iDscore_Dnuisance_C.col(0) = iDscore_Dnuisance_C.col(1);
 	iDscore_Dnuisance_C.col(1) = iTempoOperatorCol;
@@ -245,7 +254,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
 	count_obsT(iter_T,0) += iPairScore[0] * iWeight;
 	if(returnIID > 1){
 	  // iid (nuisance) for the score
-	  if(method >= 4){
+	  if(method >= 5){
 	    Dscore_Dnuisance_C.col(0) += iDscore_Dnuisance_C.col(0) * iWeight;
 	    Dscore_Dnuisance_T.col(0) += iDscore_Dnuisance_T.col(0) * iWeight;
 	  }
@@ -276,7 +285,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
 	    count_obsT(iter_T,1) += iPairScore[1] * iWeight;
 	    if(returnIID > 1){
 	      // iid (nuisance) for the score
-	      if(method >= 4){
+	      if(method >= 5){
 		Dscore_Dnuisance_C.col(1) += iDscore_Dnuisance_C.col(1) * iWeight;
 		Dscore_Dnuisance_T.col(1) += iDscore_Dnuisance_T.col(1) * iWeight;
 	      }
@@ -308,7 +317,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
 		count_obsT(iter_T,2) += iPairScore[2] * iWeight;
 		if(returnIID > 1){
 		  // iid (nuisance) for the score
-		  if(method >= 4){
+		  if(method >= 5){
 			Dscore_Dnuisance_C.col(2) += iDscore_Dnuisance_C.col(2) * iWeight;
 			Dscore_Dnuisance_T.col(2) += iDscore_Dnuisance_T.col(2) * iWeight;
 		  }
@@ -341,7 +350,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
 		count_obsT(iter_T,3) += iPairScore[3] * iWeight;
 		if(returnIID > 1){
 		  // iid (nuisance) for the score
-		  if(method >= 4){
+		  if(method >= 5){
 			Dscore_Dnuisance_C.col(3) += iDscore_Dnuisance_C.col(3) * iWeight;
 			Dscore_Dnuisance_T.col(3) += iDscore_Dnuisance_T.col(3) * iWeight;
 		  }
@@ -371,7 +380,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
 	  vec_neutral.push_back(iPairScore[2]);
 	  vec_uninformative.push_back(iPairScore[3]);
 
-	  if((returnIID > 1) && (method >= 4) && (evalM1 == false)){
+	  if((returnIID > 1) && (method >= 5) && (evalM1 == false)){
 		add4vec(vecRow_Dnuisance_C, vecCol_Dnuisance_C,
 				vecValue_Dnuisance_C[0], vecValue_Dnuisance_C[1], vecValue_Dnuisance_C[2], vecValue_Dnuisance_C[3],
 				n_RP, iDscore_Dnuisance_C);
@@ -417,7 +426,7 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
 
 	// *** iid
 	// assemble RP_Dscore_Dnuisance from the vectors
-	if((returnIID > 1) && (method >= 4)){
+	if((returnIID > 1) && (method >= 5)){
   	  // DOCUMENTATION armadillo
 	  // (locations, values, n_rows, n_cols)
 	  // locations is a dense matrix of type umat, with a size of 2 x N, where N is the number of values to be inserted;
@@ -503,6 +512,11 @@ void correctionPairs(int method, double zeroPlus,
 					 std::vector< arma::sp_mat >& RP_Dscore_Dnuisance_C, std::vector< arma::sp_mat >& RP_Dscore_Dnuisance_T, int returnIID,
 					 bool neutralAsUninf, bool keepScore, bool updateRP){
 
+  // if(count_uninf/(count_favorable+count_unfavorable+count_neutral+count_uninf)>0.1){
+  //    Rcpp::warning("Large proportion of uninformative pairs: make sure that the correction makes sense. \n") 
+  // }
+    
+  
   // compute factor
   double factorFavorable;
   double factorUnfavorable;
@@ -548,7 +562,7 @@ void correctionPairs(int method, double zeroPlus,
 		Dweight_Dnuisance_T[3][activeUTTE[iter_UTTE]] *= 0;
 	  }
 	  
-	  if(method>=4){
+	  if(method>=5){
 		Dscore_Dnuisance_C.col(0) += factorFavorable * Dscore_Dnuisance_C.col(3);
 		Dscore_Dnuisance_C.col(1) += factorUnfavorable * Dscore_Dnuisance_C.col(3);
 		Dscore_Dnuisance_C.col(2) += factorNeutral * Dscore_Dnuisance_C.col(3);
@@ -573,7 +587,7 @@ void correctionPairs(int method, double zeroPlus,
 	  RP_score.col(5) += factorNeutral * RP_score.col(6); 
 	  (RP_score.col(6)).fill(0.0);  
 		
-	  if(returnIID>1 && method>=4){
+	  if(returnIID>1 && method>=5){
 		RP_Dscore_Dnuisance_C[0] += factorFavorable * RP_Dscore_Dnuisance_C[3]; 
 		RP_Dscore_Dnuisance_C[1] += factorUnfavorable * RP_Dscore_Dnuisance_C[3]; 
 		RP_Dscore_Dnuisance_C[2] += factorNeutral * RP_Dscore_Dnuisance_C[3]; 
@@ -586,7 +600,7 @@ void correctionPairs(int method, double zeroPlus,
 	  }
 	}else{
 	  RP_score.resize(0,0);
-	  if(returnIID>1 && method>=4){
+	  if(returnIID>1 && method>=5){
 		for(int iter_typeRP=0; iter_typeRP<4; iter_typeRP++){
 		  RP_Dscore_Dnuisance_C[iter_typeRP].resize(0,0);
 		  RP_Dscore_Dnuisance_T[iter_typeRP].resize(0,0);
@@ -615,6 +629,10 @@ void correctionIPW(int method, double zeroPlus,
 				   std::vector< arma::sp_mat >& RP_Dscore_Dnuisance_C, std::vector< arma::sp_mat >& RP_Dscore_Dnuisance_T, int returnIID,
 				   bool neutralAsUninf, bool keepScore, bool updateRP){
 
+  // if(count_uninf/(count_favorable+count_unfavorable+count_neutral+count_uninf)>0.1){
+  //    Rcpp::warning("Large proportion of uninformative pairs: make sure that the correction makes sense. \n") 
+  // }
+
   // compute factor
   double factor;
   if(count_favorable + count_unfavorable + count_neutral > zeroPlus){
@@ -654,7 +672,7 @@ void correctionIPW(int method, double zeroPlus,
 		Dweight_Dnuisance_T[3][activeUTTE[iter_UTTE]] *= 0;
 	  }
 
-	  if(method>=4){
+	  if(method>=5){
 		Dscore_Dnuisance_C.col(0) *= factor;
 		Dscore_Dnuisance_C.col(1) *= factor;
 		Dscore_Dnuisance_C.col(2) *= factor;
@@ -680,7 +698,7 @@ void correctionIPW(int method, double zeroPlus,
 	  RP_score.col(5) *= factor; 
 	  (RP_score.col(6)).fill(0.0);
 	  
-	  if(returnIID>1 && method>=4){
+	  if(returnIID>1 && method>=5){
 		RP_Dscore_Dnuisance_C[0] *= factor; 
 		RP_Dscore_Dnuisance_C[1] *= factor; 
 		RP_Dscore_Dnuisance_C[2] *= factor; 
@@ -693,7 +711,7 @@ void correctionIPW(int method, double zeroPlus,
 	  }
 	}else{
 	  RP_score.resize(0,0);
-	  if(returnIID>1 && method>=4){
+	  if(returnIID>1 && method>=5){
 		for(int iter_typeRP=0; iter_typeRP<4; iter_typeRP++){
 		  RP_Dscore_Dnuisance_C[iter_typeRP].resize(0,0);
 		  RP_Dscore_Dnuisance_T[iter_typeRP].resize(0,0);
